@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::As::Parsed; # git description: v1.72-7-g8682f63
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Tie::IxHash;
 
@@ -767,7 +767,7 @@ YAML::As::Parsed - Read/Write YAML predictably
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -783,10 +783,10 @@ Assuming F<file.yml> like this:
 
 	...
 
-	use YAML::Tiny;
+	use YAML::As::Parsed;
 	 
 	# Open the config
-	my $yaml = YAML::Tiny->read( 'file.yml' );
+	my $yaml = YAML::As::Parsed->read( 'file.yml' );
 	 
 	for my $key ( keys %{ $yaml->[0]->{section} } ) {
 		print $key;
